@@ -1,35 +1,13 @@
 
 /*
-   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
-   All rights reserved.
+   SPDX-FileCopyrightText: 2003-2007 Clarence Dang <dang@kde.org>
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   1. Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-   2. Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   SPDX-License-Identifier: BSD-2-Clause
 */
 
-
 #ifndef kpToolPolygonalBase_H
 #define kpToolPolygonalBase_H
 
-
 #include <QPoint>
 #include <QRect>
 
@@ -38,14 +16,11 @@
 #include "tools/kpTool.h"
 #include "widgets/toolbars/options/kpToolWidgetFillStyle.h"
 
-
 class QPolygon;
 class QString;
 
-
 class kpToolWidgetFillStyle;
 
-
 struct kpToolPolygonalBasePrivate;
 
 //
@@ -83,37 +58,43 @@ struct kpToolPolygonalBasePrivate;
 //
 class kpToolPolygonalBase : public kpTool
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    typedef void (*DrawShapeFunc) (kpImage * /*image*/,
-        const QPolygon &/*points*/,
-        const kpColor &/*fcolor*/, int /*penWidth = 1*/,
-        const kpColor &/*bcolor = kpColor::Invalid*/,
-        bool /*isFinal*/);
+    typedef void (*DrawShapeFunc)(kpImage * /*image*/,
+                                  const QPolygon & /*points*/,
+                                  const kpColor & /*fcolor*/,
+                                  int /*penWidth = 1*/,
+                                  const kpColor & /*bcolor = kpColor::Invalid*/,
+                                  bool /*isFinal*/);
 
     // <drawShapeFunc>
-    kpToolPolygonalBase (const QString &text, const QString &description,
-        DrawShapeFunc drawShapeFunc,
-        int key,
-        kpToolEnvironment *environ, QObject *parent,
-        const QString &name);
-    ~kpToolPolygonalBase () override;
+    kpToolPolygonalBase(const QString &text,
+                        const QString &description,
+                        DrawShapeFunc drawShapeFunc,
+                        int key,
+                        kpToolEnvironment *environ,
+                        QObject *parent,
+                        const QString &name);
+    ~kpToolPolygonalBase() override;
 
-    bool careAboutModifierState () const override { return true; }
+    bool careAboutModifierState() const override
+    {
+        return true;
+    }
 
 protected:
     // The maximum number of points() we should allow (mainly, to ensure
     // good performance).  Enforced by implementors of endShape().
     static const int MaxPoints = 50;
 
-    virtual QString haventBegunShapeUserMessage () const = 0;
+    virtual QString haventBegunShapeUserMessage() const = 0;
 
 public:
-    void begin () override;
-    void end () override;
+    void begin() override;
+    void end() override;
 
-    void beginDraw () override;
+    void beginDraw() override;
 
 protected:
     // Adjusts the current line (end points given by the last 2 points of points())
@@ -134,14 +115,14 @@ protected:
     // it doesn't really make sense to call applyModifiers() (in a hypothetical
     // reimplementation of draw()) because you're not manipulating a line - but
     // you can still call applyModifiers() if you want.
-    void applyModifiers ();
+    void applyModifiers();
 
     // Returns the current points in the shape.  It is updated by beginDraw()
     // (see the class description).
     //
     // draw() sets the last point to the currentPoint().  If drawingALine(),
     // draw() then calls applyModifiers().
-    QPolygon *points () const;
+    QPolygon *points() const;
 
     // Returns the mouse button for the drag that created the initial line.
     // Use this - instead of mouseButton() - for determining whether you should
@@ -150,7 +131,7 @@ protected:
     // will return the wrong one, after the initial line).
     //
     // Only valid if kpTool::hasBegunShape() returns true.
-    int originatingMouseButton () const;
+    int originatingMouseButton() const;
 
     // Returns true if the current drag is visually a line from the 2nd last point
     // of points() to the last point of points() e.g. the initial line drag for
@@ -167,34 +148,40 @@ protected:
     // the initial drag.  However, for the following 2 control points, it returns
     // "false".  The Curve tool realizes it is an initial drag if points() only
     // returns 2 points.
-    virtual bool drawingALine () const { return true; }
+    virtual bool drawingALine() const
+    {
+        return true;
+    }
+
 public:
-    void draw (const QPoint &, const QPoint &, const QRect &) override;
+    void draw(const QPoint &, const QPoint &, const QRect &) override;
+
 private:
-    kpColor drawingForegroundColor () const;
+    kpColor drawingForegroundColor() const;
+
 protected:
     // This returns the invalid color so that there is never a fill.
     // This is in contrast to kpToolRectangularBase, which sometimes fills by
     // returning a valid color.
     //
     // Reimplemented in the Polygon tool for a fill.
-    virtual kpColor drawingBackgroundColor () const;
+    virtual kpColor drawingBackgroundColor() const;
 protected Q_SLOTS:
-    void updateShape ();
+    void updateShape();
+
 public:
-    void cancelShape () override;
-    void releasedAllButtons () override;
-    void endShape (const QPoint & = QPoint (), const QRect & = QRect ()) override;
+    void cancelShape() override;
+    void releasedAllButtons() override;
+    void endShape(const QPoint & = QPoint(), const QRect & = QRect()) override;
 
-    bool hasBegunShape () const override;
+    bool hasBegunShape() const override;
 
 protected Q_SLOTS:
-    void slotForegroundColorChanged (const kpColor &) override;
-    void slotBackgroundColorChanged (const kpColor &) override;
+    void slotForegroundColorChanged(const kpColor &) override;
+    void slotBackgroundColorChanged(const kpColor &) override;
 
 private:
-    kpToolPolygonalBasePrivate * const d;
+    kpToolPolygonalBasePrivate *const d;
 };
 
-
-#endif  // kpToolPolygonalBase_H
+#endif // kpToolPolygonalBase_H
